# corenetworks

[![Build Status](https://img.shields.io/drone/build/thegeeklab/corenetworks?logo=drone&server=https%3A%2F%2Fdrone.thegeeklab.de)](https://drone.thegeeklab.de/thegeeklab/corenetworks)
[![Python Version](https://img.shields.io/pypi/pyversions/corenetworks.svg)](https://pypi.org/project/corenetworks/)
[![PyPI Status](https://img.shields.io/pypi/status/corenetworks.svg)](https://pypi.org/project/corenetworks/)
[![PyPI Release](https://img.shields.io/pypi/v/corenetworks.svg)](https://pypi.org/project/corenetworks/)
[![Codecov](https://img.shields.io/codecov/c/github/thegeeklab/corenetworks)](https://codecov.io/gh/thegeeklab/corenetworks)
[![GitHub contributors](https://img.shields.io/github/contributors/thegeeklab/corenetworks)](https://github.com/thegeeklab/corenetworks/graphs/contributors)
[![License: MIT](https://img.shields.io/github/license/thegeeklab/corenetworks)](https://github.com/thegeeklab/corenetworks/blob/main/LICENSE)

> **Discontinued:** This project is no longer maintained.

Python library for the [https://core-networks.de](https://beta.api.core-networks.de/doc/) DNS API. You can find the full documentation at [https://corenetworks.geekdocs.de](https://corenetworks.geekdocs.de/).

## Contributors

Special thanks goes to all [contributors](https://github.com/thegeeklab/corenetworks/graphs/contributors). If you would like to contribute,
please see the [instructions](https://github.com/thegeeklab/corenetworks/blob/main/CONTRIBUTING.md).

## License

This project is licensed under the MIT License - see the [LICENSE](https://github.com/thegeeklab/corenetworks/blob/main/LICENSE) file for details.
